var dhcp6__messages_8cc =
[
    [ "isc::dhcp::DHCP4_HOOK_SUBNET6_SELECT_PARKING_LOT_FULL", "d5/d8c/namespaceisc_1_1dhcp.html#a82cc9e3fdb2048c2d6ea1121d9ddb920", null ],
    [ "isc::dhcp::DHCP6_ADD_GLOBAL_STATUS_CODE", "d5/d8c/namespaceisc_1_1dhcp.html#a5986f4801cd782fee3f8adbc96fc13fb", null ],
    [ "isc::dhcp::DHCP6_ADD_STATUS_CODE_FOR_IA", "d5/d8c/namespaceisc_1_1dhcp.html#af3dff4377db16fd2307c32dc16906184", null ],
    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_EVAL_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#a42cab2ca4b110c93a4fff74fe9e95a3f", null ],
    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_EVAL_RESULT", "d5/d8c/namespaceisc_1_1dhcp.html#a09f71d5c78d7b766176c909258dfeef4", null ],
    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_NO_TEST", "d5/d8c/namespaceisc_1_1dhcp.html#a093058e3b6bc25ad853c84b39fe16189", null ],
    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_UNDEFINED", "d5/d8c/namespaceisc_1_1dhcp.html#a2579488e0b97a362f4a8c2777192633c", null ],
    [ "isc::dhcp::DHCP6_ADDR_REG_INFORM_CLIENT_CHANGE", "d5/d8c/namespaceisc_1_1dhcp.html#a1c195c116ecc33ade0d4e024e7113707", null ],
    [ "isc::dhcp::DHCP6_ADDR_REG_INFORM_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a779c1ee8e64300b6dc2a90a516cb8056", null ],
    [ "isc::dhcp::DHCP6_ALREADY_RUNNING", "d5/d8c/namespaceisc_1_1dhcp.html#a7f407abed4e7f7873deb4a5703d1dcdd", null ],
    [ "isc::dhcp::DHCP6_BUFFER_RECEIVED", "d5/d8c/namespaceisc_1_1dhcp.html#a04936fb907d7f40ee94299ce71fd4658", null ],
    [ "isc::dhcp::DHCP6_BUFFER_UNPACK", "d5/d8c/namespaceisc_1_1dhcp.html#a2f1fe4c90d0155c1f22b638995c208f7", null ],
    [ "isc::dhcp::DHCP6_BUFFER_WAIT_SIGNAL", "d5/d8c/namespaceisc_1_1dhcp.html#ad0fa9ff709269df266180a31b144131e", null ],
    [ "isc::dhcp::DHCP6_CB_ON_DEMAND_FETCH_UPDATES_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a7043ce8d2e8c8ef00e0c1733629dbb72", null ],
    [ "isc::dhcp::DHCP6_CB_PERIODIC_FETCH_UPDATES_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a486028de9bcc989b05446d91f5b5bde1", null ],
    [ "isc::dhcp::DHCP6_CB_PERIODIC_FETCH_UPDATES_RETRIES_EXHAUSTED", "d5/d8c/namespaceisc_1_1dhcp.html#a76e9a01f0ce4d225c4d5369f7c825b26", null ],
    [ "isc::dhcp::DHCP6_CLASS_ASSIGNED", "d5/d8c/namespaceisc_1_1dhcp.html#abff43ad65ae0c3a367edd98414cee76c", null ],
    [ "isc::dhcp::DHCP6_CLASS_UNCONFIGURED", "d5/d8c/namespaceisc_1_1dhcp.html#ab9cae6eadd2144e30f1d2499593b9d31", null ],
    [ "isc::dhcp::DHCP6_CLASSES_ASSIGNED", "d5/d8c/namespaceisc_1_1dhcp.html#a5c3c9d208860dc98749486fd4b92e6f9", null ],
    [ "isc::dhcp::DHCP6_CLASSES_ASSIGNED_AFTER_SUBNET_SELECTION", "d5/d8c/namespaceisc_1_1dhcp.html#adacfcd01d476bc39d451026d2d6797da", null ],
    [ "isc::dhcp::DHCP6_CONFIG_COMPLETE", "d5/d8c/namespaceisc_1_1dhcp.html#a4c8e06c34af0c9b310831b53a6fd0dc6", null ],
    [ "isc::dhcp::DHCP6_CONFIG_LOAD_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a17df57739ca4f2aa09f3726d0a9fab99", null ],
    [ "isc::dhcp::DHCP6_CONFIG_PACKET_QUEUE", "d5/d8c/namespaceisc_1_1dhcp.html#affda54f1d8e5b582bd96e642dd8d8beb", null ],
    [ "isc::dhcp::DHCP6_CONFIG_RECEIVED", "d5/d8c/namespaceisc_1_1dhcp.html#ab2643414db16fdf529410602f6648101", null ],
    [ "isc::dhcp::DHCP6_CONFIG_START", "d5/d8c/namespaceisc_1_1dhcp.html#ab645c83817435b0d40367e739ec96366", null ],
    [ "isc::dhcp::DHCP6_CONFIG_SYNTAX_WARNING", "d5/d8c/namespaceisc_1_1dhcp.html#a28896879e5362d2355e9c79ad93e1aa7", null ],
    [ "isc::dhcp::DHCP6_CONFIG_UNRECOVERABLE_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#aa1ba860b8cfbb5886dce6ac94e780e63", null ],
    [ "isc::dhcp::DHCP6_CONFIG_UNSUPPORTED_OBJECT", "d5/d8c/namespaceisc_1_1dhcp.html#a9cfe606adaef71577a2d611f48d7fc9e", null ],
    [ "isc::dhcp::DHCP6_DATA_DIRECTORY_DEPRECATED", "d5/d8c/namespaceisc_1_1dhcp.html#a304680d2bb59f5eea0b9cdc4738466fc", null ],
    [ "isc::dhcp::DHCP6_DB_RECONNECT_DISABLED", "d5/d8c/namespaceisc_1_1dhcp.html#ab33550c696ffab5c71bd858d1d38a212", null ],
    [ "isc::dhcp::DHCP6_DB_RECONNECT_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#af12214342ce3153b4a34aba9c2054dd6", null ],
    [ "isc::dhcp::DHCP6_DB_RECONNECT_LOST_CONNECTION", "d5/d8c/namespaceisc_1_1dhcp.html#ad29ec2308b248e5b24f23c0e498adccf", null ],
    [ "isc::dhcp::DHCP6_DB_RECONNECT_NO_DB_CTL", "d5/d8c/namespaceisc_1_1dhcp.html#a0f6209a98536c23b3d895f03007997b3", null ],
    [ "isc::dhcp::DHCP6_DB_RECONNECT_SUCCEEDED", "d5/d8c/namespaceisc_1_1dhcp.html#a3814b1fd87c467ef301cfb4d21b8e806", null ],
    [ "isc::dhcp::DHCP6_DDNS_CREATE_ADD_NAME_CHANGE_REQUEST", "d5/d8c/namespaceisc_1_1dhcp.html#af3248bf9e4ce23d59dff51a5f7bcba96", null ],
    [ "isc::dhcp::DHCP6_DDNS_FQDN_GENERATED", "d5/d8c/namespaceisc_1_1dhcp.html#afb89701b207967460e7f6889929fb8b2", null ],
    [ "isc::dhcp::DHCP6_DDNS_GENERATE_FQDN", "d5/d8c/namespaceisc_1_1dhcp.html#a4db70420ce8c93a09a239442edc49e6e", null ],
    [ "isc::dhcp::DHCP6_DDNS_GENERATED_FQDN_UPDATE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#aa4b2b8d02d2feb7ff6b03621625865b1", null ],
    [ "isc::dhcp::DHCP6_DDNS_RECEIVE_FQDN", "d5/d8c/namespaceisc_1_1dhcp.html#a93f55da9ff25be91e26e3c311d9568c0", null ],
    [ "isc::dhcp::DHCP6_DDNS_REMOVE_OLD_LEASE_FQDN", "d5/d8c/namespaceisc_1_1dhcp.html#a5272b73a5ae4e7ef84e682e4dff0af2d", null ],
    [ "isc::dhcp::DHCP6_DDNS_REQUEST_SEND_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a001c45f5b420a44d378ce4d909042924", null ],
    [ "isc::dhcp::DHCP6_DDNS_RESPONSE_FQDN_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#a5ad1ece40d4adf47b453aae1ac5b3fde", null ],
    [ "isc::dhcp::DHCP6_DECLINE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#aa789585dfbb10c894b17310935ad7799", null ],
    [ "isc::dhcp::DHCP6_DECLINE_FAIL_DUID_MISMATCH", "d5/d8c/namespaceisc_1_1dhcp.html#acc9237c459dcc85d23f5fd64bfad1b58", null ],
    [ "isc::dhcp::DHCP6_DECLINE_FAIL_IAID_MISMATCH", "d5/d8c/namespaceisc_1_1dhcp.html#a7962ba9bbc36c5309ba5ba3a80632ebe", null ],
    [ "isc::dhcp::DHCP6_DECLINE_FAIL_LEASE_WITHOUT_DUID", "d5/d8c/namespaceisc_1_1dhcp.html#a35b8858da86928695fc519eeabd705c2", null ],
    [ "isc::dhcp::DHCP6_DECLINE_FAIL_NO_LEASE", "d5/d8c/namespaceisc_1_1dhcp.html#ad0ec7458cb45fbafb70411038ac8bb5d", null ],
    [ "isc::dhcp::DHCP6_DECLINE_LEASE", "d5/d8c/namespaceisc_1_1dhcp.html#a8575e351ef4786ce95a8199eef16923e", null ],
    [ "isc::dhcp::DHCP6_DECLINE_PROCESS_IA", "d5/d8c/namespaceisc_1_1dhcp.html#ab2beab6f9bb9ac9599dcc6703ead4e7f", null ],
    [ "isc::dhcp::DHCP6_DEVELOPMENT_VERSION", "d5/d8c/namespaceisc_1_1dhcp.html#a50cc7f6cfcdaffcb3c593c6a5178571c", null ],
    [ "isc::dhcp::DHCP6_DHCP4O6_PACKET_RECEIVED", "d5/d8c/namespaceisc_1_1dhcp.html#a11d9f1373b362d5e82d612d8915c8fdd", null ],
    [ "isc::dhcp::DHCP6_DHCP4O6_RECEIVE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#ac2ab4c9a650270cd9539e87381552242", null ],
    [ "isc::dhcp::DHCP6_DHCP4O6_RECEIVING", "d5/d8c/namespaceisc_1_1dhcp.html#a00389f1f02bb6affb80a755af5342ae1", null ],
    [ "isc::dhcp::DHCP6_DHCP4O6_RESPONSE_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#a18b39b0018938216eb261b98f9de74e5", null ],
    [ "isc::dhcp::DHCP6_DHCP4O6_SEND_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#ab34811b4c0c9ee90eb67aecede7f9cdd", null ],
    [ "isc::dhcp::DHCP6_DYNAMIC_RECONFIGURATION", "d5/d8c/namespaceisc_1_1dhcp.html#ab690fc574030e437a779e1b6352b135b", null ],
    [ "isc::dhcp::DHCP6_DYNAMIC_RECONFIGURATION_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a973b5fa2c89b7ff6bef5b93c2a3140f1", null ],
    [ "isc::dhcp::DHCP6_DYNAMIC_RECONFIGURATION_SUCCESS", "d5/d8c/namespaceisc_1_1dhcp.html#a62d40aa538e0e188d0dc21a7cad12251", null ],
    [ "isc::dhcp::DHCP6_FLEX_ID", "d5/d8c/namespaceisc_1_1dhcp.html#a11a176cae92cbbdf0ba2f103e84540d8", null ],
    [ "isc::dhcp::DHCP6_HOOK_ADDR6_REGISTER_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#ae3df3d2d2a43b80d7cf9d9472bfe8208", null ],
    [ "isc::dhcp::DHCP6_HOOK_ADDR6_REGISTER_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#a9c8a9685780f2c503c42483d2ea263ec", null ],
    [ "isc::dhcp::DHCP6_HOOK_BUFFER_RCVD_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#aef0babbda3e8a607c1e2cd631791181f", null ],
    [ "isc::dhcp::DHCP6_HOOK_BUFFER_RCVD_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#aa77f57a64c27cb4e187857179032a646", null ],
    [ "isc::dhcp::DHCP6_HOOK_BUFFER_SEND_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#af5a746ffc3464f256fb5de89f4b14165", null ],
    [ "isc::dhcp::DHCP6_HOOK_DDNS_UPDATE", "d5/d8c/namespaceisc_1_1dhcp.html#a47433198bd11aa47099dc6ea05a9845d", null ],
    [ "isc::dhcp::DHCP6_HOOK_DECLINE_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#abb4aacd829ba23ddcc71767ee6cb298c", null ],
    [ "isc::dhcp::DHCP6_HOOK_DECLINE_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#a1fa82f0758fd2629a201b748a21aa06d", null ],
    [ "isc::dhcp::DHCP6_HOOK_LEASE6_RELEASE_NA_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#a4ae22fa0d83a6feff8d447a107165c45", null ],
    [ "isc::dhcp::DHCP6_HOOK_LEASE6_RELEASE_PD_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#af8936c2d8e62fe3ac749f2c2bdea66c3", null ],
    [ "isc::dhcp::DHCP6_HOOK_LEASES6_COMMITTED_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#aa1fb2424e15bbc08f44cd2c1eb8af292", null ],
    [ "isc::dhcp::DHCP6_HOOK_LEASES6_COMMITTED_PARK", "d5/d8c/namespaceisc_1_1dhcp.html#acec360914441553896efe20f2029512d", null ],
    [ "isc::dhcp::DHCP6_HOOK_LEASES6_PARKING_LOT_FULL", "d5/d8c/namespaceisc_1_1dhcp.html#a887e6ce2960f9e474916c509c409406f", null ],
    [ "isc::dhcp::DHCP6_HOOK_PACKET_RCVD_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#a38eab5d5681ab1a047657fc3d1803b9e", null ],
    [ "isc::dhcp::DHCP6_HOOK_PACKET_SEND_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#aa22477aa5d9a2b8cc6a4302c822ad348", null ],
    [ "isc::dhcp::DHCP6_HOOK_PACKET_SEND_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#a177c6d8cf274677b41755d3c42201384", null ],
    [ "isc::dhcp::DHCP6_HOOK_SUBNET6_SELECT_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#a593fae8ee6ce48fd9e3da4d1ca2b4302", null ],
    [ "isc::dhcp::DHCP6_HOOK_SUBNET6_SELECT_PARK", "d5/d8c/namespaceisc_1_1dhcp.html#a7c4011ca93b8ac41560a729c719c6dde", null ],
    [ "isc::dhcp::DHCP6_HOOK_SUBNET6_SELECT_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#abddb74a5ed76427c7dea3f5c0be912ad", null ],
    [ "isc::dhcp::DHCP6_INIT_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a3df7ef34825c122db2e2509c5a9e8ba2", null ],
    [ "isc::dhcp::DHCP6_LEASE_ADVERT", "d5/d8c/namespaceisc_1_1dhcp.html#ac9e9b5aa5a7e04a95f4b649833a86cd0", null ],
    [ "isc::dhcp::DHCP6_LEASE_ADVERT_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a8723f87896e2665b4ebca9995cdb654f", null ],
    [ "isc::dhcp::DHCP6_LEASE_ALLOC", "d5/d8c/namespaceisc_1_1dhcp.html#a0ea60a1d66395f19231f40da4ba408df", null ],
    [ "isc::dhcp::DHCP6_LEASE_ALLOC_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a233c2388193b90ab41f0fc517112efce", null ],
    [ "isc::dhcp::DHCP6_LEASE_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#af4f1ad1636eb0f6b72ed379f0f085c11", null ],
    [ "isc::dhcp::DHCP6_LEASE_NA_WITHOUT_DUID", "d5/d8c/namespaceisc_1_1dhcp.html#aba8032fb83e7798a13030d3593499d18", null ],
    [ "isc::dhcp::DHCP6_LEASE_PD_WITHOUT_DUID", "d5/d8c/namespaceisc_1_1dhcp.html#a21bd20613a33f5e61e9aa842b27b1245", null ],
    [ "isc::dhcp::DHCP6_LEASE_RENEW", "d5/d8c/namespaceisc_1_1dhcp.html#a67c5fa8cdababc2dd388c0fd8f3cef87", null ],
    [ "isc::dhcp::DHCP6_LEASE_REUSE", "d5/d8c/namespaceisc_1_1dhcp.html#a98d4f37b07ff85387cba0c4873a75e9b", null ],
    [ "isc::dhcp::DHCP6_MULTI_THREADING_INFO", "d5/d8c/namespaceisc_1_1dhcp.html#aed3790e801d9e29a6ae69c920fd714d5", null ],
    [ "isc::dhcp::DHCP6_NO_INTERFACES", "d5/d8c/namespaceisc_1_1dhcp.html#a95e054a17a2b948323be4e8f44c6b06f", null ],
    [ "isc::dhcp::DHCP6_NOT_RUNNING", "d5/d8c/namespaceisc_1_1dhcp.html#a7b9428be18d8b0725074fbc96242a556", null ],
    [ "isc::dhcp::DHCP6_OPEN_SOCKET", "d5/d8c/namespaceisc_1_1dhcp.html#a445a842c31fa46d8ab673e6e791afc67", null ],
    [ "isc::dhcp::DHCP6_OPEN_SOCKETS_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a55ba24022df92feab6508beb7442fae6", null ],
    [ "isc::dhcp::DHCP6_OPEN_SOCKETS_NO_RECONNECT_CTL", "d5/d8c/namespaceisc_1_1dhcp.html#a126eca4f33d4110114094b99df593d60", null ],
    [ "isc::dhcp::DHCP6_PACK_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a44f580c657aed0095a6b72cfb4c2491c", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_DHCP_DISABLED", "d5/d8c/namespaceisc_1_1dhcp.html#afca325a9a9aeefb14f95cde5cc6f016a", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_DROP_CLASS", "d5/d8c/namespaceisc_1_1dhcp.html#aaf96ac8368be7ec2251a9b191d637d5c", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_DROP_CLASS2", "d5/d8c/namespaceisc_1_1dhcp.html#aa52b234e5ff739159ca836ee5db92731", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_DROP_CLASS_EARLY", "d5/d8c/namespaceisc_1_1dhcp.html#ac9d932fc51bc0ef94626cf1870396465", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_DUPLICATE", "d5/d8c/namespaceisc_1_1dhcp.html#af47799525f20150303905dd255783cfb", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_PARSE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a08d205a8fca2e6be2b286e7edfd8762b", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_SERVERID_MISMATCH", "d5/d8c/namespaceisc_1_1dhcp.html#a1f4b16807c961f5fbc078e778a1f62a9", null ],
    [ "isc::dhcp::DHCP6_PACKET_DROP_UNICAST", "d5/d8c/namespaceisc_1_1dhcp.html#a212adf4a21fd22ab6390934b49072d17", null ],
    [ "isc::dhcp::DHCP6_PACKET_OPTIONS_SKIPPED", "d5/d8c/namespaceisc_1_1dhcp.html#a942825d47a354ee3b0f5d7d7d7ec2a31", null ],
    [ "isc::dhcp::DHCP6_PACKET_PROCESS_EXCEPTION", "d5/d8c/namespaceisc_1_1dhcp.html#a2723b6234e4bd8568135ea9b81f9e017", null ],
    [ "isc::dhcp::DHCP6_PACKET_PROCESS_EXCEPTION_MAIN", "d5/d8c/namespaceisc_1_1dhcp.html#a17627716f671c6506fa166c60abca0a6", null ],
    [ "isc::dhcp::DHCP6_PACKET_PROCESS_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a8b68b7d5aed420f68689e4587b99b939", null ],
    [ "isc::dhcp::DHCP6_PACKET_PROCESS_STD_EXCEPTION", "d5/d8c/namespaceisc_1_1dhcp.html#a722d116d505d0055f0f9e31a440d66eb", null ],
    [ "isc::dhcp::DHCP6_PACKET_PROCESS_STD_EXCEPTION_MAIN", "d5/d8c/namespaceisc_1_1dhcp.html#adbd29dcf38354c791e844b1cd879a027", null ],
    [ "isc::dhcp::DHCP6_PACKET_QUEUE_FULL", "d5/d8c/namespaceisc_1_1dhcp.html#af7c0f0a9c5afc4900ea7f6093e7b9b3b", null ],
    [ "isc::dhcp::DHCP6_PACKET_RECEIVE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a733ea3323bb1eba2eba62ce8026a19d7", null ],
    [ "isc::dhcp::DHCP6_PACKET_RECEIVED", "d5/d8c/namespaceisc_1_1dhcp.html#a922eed3feb72e12a87e5bc5949cf8b2b", null ],
    [ "isc::dhcp::DHCP6_PACKET_SEND", "d5/d8c/namespaceisc_1_1dhcp.html#a31bb40fc093dc8b707fb6b126bc89b11", null ],
    [ "isc::dhcp::DHCP6_PACKET_SEND_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a26b8cb5767dfc9215c94e97c72dd7123", null ],
    [ "isc::dhcp::DHCP6_PARSER_COMMIT_EXCEPTION", "d5/d8c/namespaceisc_1_1dhcp.html#ab625bb3178050f58a08a80a27e96ecac", null ],
    [ "isc::dhcp::DHCP6_PARSER_COMMIT_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#ad3b26e7a2876b7fd44de1508b341bca4", null ],
    [ "isc::dhcp::DHCP6_PARSER_EXCEPTION", "d5/d8c/namespaceisc_1_1dhcp.html#a1daab952d949f681eeded27bc5257c6b", null ],
    [ "isc::dhcp::DHCP6_PARSER_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a1ae5ba563b8a7c8bf0a5a55ca940e931", null ],
    [ "isc::dhcp::DHCP6_PD_LEASE_ADVERT", "d5/d8c/namespaceisc_1_1dhcp.html#a01e86d4eea2df4498566f5ff9520380d", null ],
    [ "isc::dhcp::DHCP6_PD_LEASE_ADVERT_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a8a621442e7261f4d084055a8628e653b", null ],
    [ "isc::dhcp::DHCP6_PD_LEASE_ALLOC", "d5/d8c/namespaceisc_1_1dhcp.html#a4cdc7d13f727df8a33ff48f703da7315", null ],
    [ "isc::dhcp::DHCP6_PD_LEASE_ALLOC_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#af7e89f1351a60441b0fb2862ea9f52ed", null ],
    [ "isc::dhcp::DHCP6_PD_LEASE_RENEW", "d5/d8c/namespaceisc_1_1dhcp.html#abeccb9967b516e802a57ea0d6f8a5dc8", null ],
    [ "isc::dhcp::DHCP6_PD_LEASE_REUSE", "d5/d8c/namespaceisc_1_1dhcp.html#a20c2a23f4b7fde559fa33e5090e6cf1f", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_NA_EXTEND", "d5/d8c/namespaceisc_1_1dhcp.html#a62f7690cfc5ecbf2903be236de77b826", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_NA_RELEASE", "d5/d8c/namespaceisc_1_1dhcp.html#ac97541e6fcf58f0e120f16dc23c983e6", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_NA_REQUEST", "d5/d8c/namespaceisc_1_1dhcp.html#ab56f168b6328222031cc1905f59e5c9f", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_NA_SOLICIT", "d5/d8c/namespaceisc_1_1dhcp.html#a7580e7d22cd1eeef94a1b4a6d8551140", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_PD_EXTEND", "d5/d8c/namespaceisc_1_1dhcp.html#ad731443837796478e14e50716db8f5b1", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_PD_REQUEST", "d5/d8c/namespaceisc_1_1dhcp.html#abd52ec0f7a0c0af1683d6cde287261db", null ],
    [ "isc::dhcp::DHCP6_PROCESS_IA_PD_SOLICIT", "d5/d8c/namespaceisc_1_1dhcp.html#aaf4a00b9a92ebe32c8590c6d2ec882fe", null ],
    [ "isc::dhcp::DHCP6_QUERY_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#aa9d26f28200182c44fd601b4de0fb74a", null ],
    [ "isc::dhcp::DHCP6_QUERY_LABEL", "d5/d8c/namespaceisc_1_1dhcp.html#a2957a3457aec1dff036dd953d267fdab", null ],
    [ "isc::dhcp::DHCP6_RAPID_COMMIT", "d5/d8c/namespaceisc_1_1dhcp.html#ad0f7626624a723fe37529e0f41df5179", null ],
    [ "isc::dhcp::DHCP6_RECLAIM_EXPIRED_LEASES_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a4c8876e76807b529b8b8a3c24d7b091d", null ],
    [ "isc::dhcp::DHCP6_RECLAIM_EXPIRED_LEASES_SKIPPED", "d5/d8c/namespaceisc_1_1dhcp.html#a3bbeca1b4ec98724ae0c8d6a5a265f01", null ],
    [ "isc::dhcp::DHCP6_REGISTERED_LEASE_ADD_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a120db9f6a2a3bd5bdaa3842d6f6fcdb5", null ],
    [ "isc::dhcp::DHCP6_REGISTERED_LEASE_UPDATE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a313d1a8ddfe17d65b66769b4dfa11743", null ],
    [ "isc::dhcp::DHCP6_RELEASE_NA", "d5/d8c/namespaceisc_1_1dhcp.html#a5b8e50af45d50bb221accd49eac070fa", null ],
    [ "isc::dhcp::DHCP6_RELEASE_NA_DELETED", "d5/d8c/namespaceisc_1_1dhcp.html#a0626ba8edb39fdcfb69290c6c4f9b8b0", null ],
    [ "isc::dhcp::DHCP6_RELEASE_NA_EXPIRED", "d5/d8c/namespaceisc_1_1dhcp.html#a91563e13dd131fddfd23d32eded6793f", null ],
    [ "isc::dhcp::DHCP6_RELEASE_NA_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a6944a2d5cf3498979f3dd03ebc443bfd", null ],
    [ "isc::dhcp::DHCP6_RELEASE_NA_FAIL_WRONG_DUID", "d5/d8c/namespaceisc_1_1dhcp.html#af35c9715a49a7fb6e2e5531ce3ae6090", null ],
    [ "isc::dhcp::DHCP6_RELEASE_NA_FAIL_WRONG_IAID", "d5/d8c/namespaceisc_1_1dhcp.html#ae6b56f4d3aec9fb1e43e9892823cd25e", null ],
    [ "isc::dhcp::DHCP6_RELEASE_PD", "d5/d8c/namespaceisc_1_1dhcp.html#af93182d0d82e5de0b46fde5941c82c72", null ],
    [ "isc::dhcp::DHCP6_RELEASE_PD_DELETED", "d5/d8c/namespaceisc_1_1dhcp.html#a0b595a6eeaf219df9d45c5166e91ea03", null ],
    [ "isc::dhcp::DHCP6_RELEASE_PD_EXPIRED", "d5/d8c/namespaceisc_1_1dhcp.html#a4eb76568ee7a1859e6d4876e069e84cb", null ],
    [ "isc::dhcp::DHCP6_RELEASE_PD_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a6338eec98952d611df294674d1e38609", null ],
    [ "isc::dhcp::DHCP6_RELEASE_PD_FAIL_WRONG_DUID", "d5/d8c/namespaceisc_1_1dhcp.html#a95f39ed55f151c9bd1578256b24156ae", null ],
    [ "isc::dhcp::DHCP6_RELEASE_PD_FAIL_WRONG_IAID", "d5/d8c/namespaceisc_1_1dhcp.html#a46f0c4aa8e6bc91e56923be8fe64fba9", null ],
    [ "isc::dhcp::DHCP6_REQUIRED_OPTIONS_CHECK_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a5f1390211542afeba52c19fae013ad15", null ],
    [ "isc::dhcp::DHCP6_RESERVATIONS_LOOKUP_FIRST_ENABLED", "d5/d8c/namespaceisc_1_1dhcp.html#a74ae56eb998780aa80e5f91379f5e704", null ],
    [ "isc::dhcp::DHCP6_RESPONSE_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#a9274654c848e4cec10ff51ac2e5cea51", null ],
    [ "isc::dhcp::DHCP6_ROOT_USER_SECURITY_WARNING", "d5/d8c/namespaceisc_1_1dhcp.html#a90c3798acefc37ff78df6597bc1c33db", null ],
    [ "isc::dhcp::DHCP6_SECURITY_CHECKS_DISABLED", "d5/d8c/namespaceisc_1_1dhcp.html#a7f22485f9bed24a0949d110679c9857c", null ],
    [ "isc::dhcp::DHCP6_SERVER_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a4d5fde11e41589c1a3b57214b4e5a19d", null ],
    [ "isc::dhcp::DHCP6_SHUTDOWN", "d5/d8c/namespaceisc_1_1dhcp.html#a644cfed2f9bf7d22ad81193c92b7fa76", null ],
    [ "isc::dhcp::DHCP6_SHUTDOWN_REQUEST", "d5/d8c/namespaceisc_1_1dhcp.html#aa7638f485c9fa83949c9e6bd89b949e7", null ],
    [ "isc::dhcp::DHCP6_SRV_CONSTRUCT_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#a666f6cd29898db9d764798148cce12c0", null ],
    [ "isc::dhcp::DHCP6_SRV_D2STOP_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#a307d00cdb40f2348754d2f95fb3bf2f5", null ],
    [ "isc::dhcp::DHCP6_SRV_UNLOAD_LIBRARIES_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#acebe5398bb6fb9d0a097df0f2b580734", null ],
    [ "isc::dhcp::DHCP6_START_INFO", "d5/d8c/namespaceisc_1_1dhcp.html#a6e55469155928664d15d56fca7e7ce16", null ],
    [ "isc::dhcp::DHCP6_STARTED", "d5/d8c/namespaceisc_1_1dhcp.html#a67a4a86ff36b69005c791564de3a5031", null ],
    [ "isc::dhcp::DHCP6_STARTING", "d5/d8c/namespaceisc_1_1dhcp.html#a6b3e033ae3c9f86e9b25b59c1cbca447", null ],
    [ "isc::dhcp::DHCP6_SUBNET_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#a54f030e8bdd122ba4b58cfc7941f7503", null ],
    [ "isc::dhcp::DHCP6_SUBNET_DYNAMICALLY_CHANGED", "d5/d8c/namespaceisc_1_1dhcp.html#af72e5eeddfbe05ef5ef511937502929d", null ],
    [ "isc::dhcp::DHCP6_SUBNET_SELECTED", "d5/d8c/namespaceisc_1_1dhcp.html#ae5f2482198b63f23acb537079dbd8bbd", null ],
    [ "isc::dhcp::DHCP6_SUBNET_SELECTION_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a1c3de1c4157c1b47dfb7c94f0f960f9e", null ],
    [ "isc::dhcp::DHCP6_UNKNOWN_MSG_RECEIVED", "d5/d8c/namespaceisc_1_1dhcp.html#a5679849e04f498187350cde2545b8057", null ],
    [ "isc::dhcp::DHCP6_USING_SERVERID", "d5/d8c/namespaceisc_1_1dhcp.html#a14a57a499fec7d1d0ef860da8fc2a405", null ]
];